RemoteMessage class

A class representing a message sent from Firebase Cloud Messaging.

Constructors

RemoteMessage({String? senderId, String? category, String? actionIdentifier, String? collapseKey, bool contentAvailable = false, Map<String, dynamic> data = const <String, dynamic>{}, String? from, String? messageId, String? messageType, bool mutableContent = false, RemoteNotification? notification, DateTime? sentTime, String? threadId, int? ttl})
const
RemoteMessage.fromMap(Map<String, dynamic> map)
Constructs a RemoteMessage from a raw Map.
factory

Properties

actionIdentifier String?
The Apple notification action identifier used to open the app.
final
category String?
The iOS category this notification is assigned to.
final
collapseKey String?
The collapse key a message was sent with. Used to override existing messages with the same key.
final
contentAvailable bool
Whether the iOS APNs message was configured as a background update notification.
final
data Map<String, dynamic>
Any additional data sent with the message.
final
from String?
The topic name or message identifier.
final
hashCode int
The hash code for this object.
no setterinherited
messageId String?
A unique ID assigned to every message.
final
messageType String?
The message type of the message.
final
mutableContent bool
Whether the iOS APNs mutable-content property on the message was set allowing the app to modify the notification via app extensions.
final
notification RemoteNotification?
Additional Notification data sent with the message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId String?
The ID of the upstream sender location.
final
sentTime DateTime?
The time the message was sent, represented as a DateTime.
final
threadId String?
An iOS app specific identifier used for notification grouping.
final
ttl int?
The time to live for the message in seconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Returns the RemoteMessage as a raw Map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited